printer/templateprinter.go
changeset 83 57afac822019
parent 51 300ac09051a7
child 85 a4464c0b0c36
--- a/printer/templateprinter.go	Sun May 07 11:56:37 2017 +0200
+++ b/printer/templateprinter.go	Sun May 07 13:06:47 2017 +0200
@@ -33,9 +33,9 @@
 }
 
 // NewPrinterTemplate returns a Template ResourcePrinter
-// For TemplatePrinter, the option parameter contains the template string.
-func NewPrinterTemplate(option string) (*TemplatePrinter, error) {
-	tmpl := option
+// For TemplatePrinter, the options parameter contains the template string.
+func NewPrinterTemplate(options Options) (*TemplatePrinter, error) {
+	tmpl := options["template"]
 	t, err := template.New("output").Funcs(template.FuncMap{
 		"fromhtml": html2string,
 		"fromunix": unix2string,